# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.3.3.1](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.12.3 
from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic import ConfigDict
from pydantic import Field
from uuid import UUID
import typing

class AIModelError(IntEnum):
    NO_ERROR = 0
    ALREADY_EXISTS = 1
    NOT_FOUND = 2
    NOT_UPDATED = 3
    NOT_AUTHORIZED = 4
    AIMODEL_OUT_OF_CREDITS = 5
    AIMODEL_DONT_HANDLE_COMPLETION = 6

class AIModel(BaseModel):
    id: typing.Optional[UUID] = Field(default="")
    name: typing.Optional[str] = Field(default="")
    provider: typing.Optional[str] = Field(default="")
    image: typing.Optional[str] = Field(default="")
    enabled: typing.Optional[bool] = Field(default=False)
    type: typing.Optional[str] = Field(default="")
    restricted: typing.Optional[bool] = Field(default=False)
    name_alias: typing.Optional[str] = Field(default="")
    context_window: typing.Optional[int] = Field(default=0)

class CompletionResponse(BaseModel):
    model_id: typing.Optional[UUID] = Field(default="")
    completions: typing.List[str] = Field(default_factory=list)
    input_tokens: typing.Optional[int] = Field(default=0)
    output_tokens: typing.Optional[int] = Field(default=0)
    image_resolution: typing.Optional[str] = Field(default="")
    image_steps: typing.Optional[int] = Field(default=0)

class AIModelResponseError(BaseModel):
    model_config = ConfigDict(validate_default=True)
    code: typing.Optional[AIModelError] = Field(default=0)
    status: typing.Optional[str] = Field(default="")
    reason: typing.Optional[str] = Field(default="")
    message: typing.Optional[str] = Field(default="")

class AIModelListRequest(BaseModel):
    page_size: typing.Optional[int] = Field(default=0)
    page_number: typing.Optional[int] = Field(default=0)

class AIModelListResponse(BaseModel):
    aimodels: typing.List[AIModel] = Field(default_factory=list)
    page_number: typing.Optional[int] = Field(default=0)
    error: typing.Optional[AIModelResponseError] = Field(default_factory=AIModelResponseError)

class AIModelGetRequest(BaseModel):
    id: typing.Optional[UUID] = Field(default="")

class AIModelGetResponse(BaseModel):
    aimodel: typing.Optional[AIModel] = Field(default_factory=AIModel)
    error: typing.Optional[AIModelResponseError] = Field(default_factory=AIModelResponseError)

class AIModelCompletionRequest(BaseModel):
    id: typing.Optional[UUID] = Field(default="")
    payload: typing.Optional[str] = Field(default="")

class AIModelCompletionResponse(BaseModel):
    completion: typing.Optional[CompletionResponse] = Field(default_factory=CompletionResponse)
    error: typing.Optional[AIModelResponseError] = Field(default_factory=AIModelResponseError)

class AIModelAdminCreationRequest(BaseModel):
    name: typing.Optional[str] = Field(default="")
    provider: typing.Optional[str] = Field(default="")
    image: typing.Optional[str] = Field(default="")
    enabled: typing.Optional[bool] = Field(default=False)
    type: typing.Optional[str] = Field(default="")
    restricted: typing.Optional[bool] = Field(default=False)
    name_alias: typing.Optional[str] = Field(default="")

class AIModelAdminCreationResponse(BaseModel):
    aimodel: typing.Optional[AIModel] = Field(default_factory=AIModel)
    error: typing.Optional[AIModelResponseError] = Field(default_factory=AIModelResponseError)

class AIModelAdminDeleteRequest(BaseModel):
    id: typing.Optional[UUID] = Field(default="")

class AIModelAdminDeleteResponse(BaseModel):
    error: typing.Optional[AIModelResponseError] = Field(default_factory=AIModelResponseError)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workspace.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2
import naas_models.errors_pb2 as errors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fworkspace.proto\x12\tworkspace\x1a\x0evalidate.proto\x1a\x0c\x65rrors.proto\"\xd3\x04\n\tWorkspace\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08\x66\x61v_icon\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nlarge_logo\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\nsmall_logo\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1b\n\x0etertiary_color\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x1f\n\x12text_primary_color\x18\t \x01(\tH\x08\x88\x01\x01\x12!\n\x14text_secondary_color\x18\n \x01(\tH\t\x88\x01\x01\x12\x18\n\x0bis_personal\x18\x0b \x01(\x08H\n\x88\x01\x01\x12\x17\n\ncreated_at\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12(\n\x11\x64\x65\x66\x61ult_plugin_id\x18\r \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x0c\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_nameB\x0b\n\t_fav_iconB\r\n\x0b_large_logoB\r\n\x0b_small_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x11\n\x0f_tertiary_colorB\x15\n\x13_text_primary_colorB\x17\n\x15_text_secondary_colorB\x0e\n\x0c_is_personalB\r\n\x0b_created_atB\x14\n\x12_default_plugin_id\"\xd1\x03\n\x11WorkspaceCreation\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66\x61v_icon\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nlarge_logo\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nsmall_logo\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x1b\n\x0etertiary_color\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1f\n\x12text_primary_color\x18\x08 \x01(\tH\x07\x88\x01\x01\x12!\n\x14text_secondary_color\x18\t \x01(\tH\x08\x88\x01\x01\x12\x18\n\x0bis_personal\x18\n \x01(\x08H\t\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_fav_iconB\r\n\x0b_large_logoB\r\n\x0b_small_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x11\n\x0f_tertiary_colorB\x15\n\x13_text_primary_colorB\x17\n\x15_text_secondary_colorB\x0e\n\x0c_is_personal\"\xe5\x03\n\x0fWorkspaceUpdate\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66\x61v_icon\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nlarge_logo\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nsmall_logo\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x1b\n\x0etertiary_color\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x1f\n\x12text_primary_color\x18\t \x01(\tH\x07\x88\x01\x01\x12!\n\x14text_secondary_color\x18\n \x01(\tH\x08\x88\x01\x01\x12(\n\x11\x64\x65\x66\x61ult_plugin_id\x18\x0b \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\t\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_fav_iconB\r\n\x0b_large_logoB\r\n\x0b_small_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x11\n\x0f_tertiary_colorB\x15\n\x13_text_primary_colorB\x17\n\x15_text_secondary_colorB\x14\n\x12_default_plugin_id\"\xde\x03\n\rWorkspaceUser\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12.\n\x04role\x18\x03 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x02\x88\x01\x01\x12\x35\n\x06status\x18\x04 \x01(\tB \xfa\x42\x1dr\x1bR\x06\x61\x63tiveR\x07invitedR\x08\x64\x65\x63linedH\x03\x88\x01\x01\x12\x16\n\tcreate_at\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x16\n\tupdate_at\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x17\n\nfirst_name\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x16\n\tlast_name\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x12\n\x05\x65mail\x18\t \x01(\tH\x08\x88\x01\x01\x12 \n\x13profile_picture_url\x18\n \x01(\tH\t\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_idB\x07\n\x05_roleB\t\n\x07_statusB\x0c\n\n_create_atB\x0c\n\n_update_atB\r\n\x0b_first_nameB\x0c\n\n_last_nameB\x08\n\x06_emailB\x16\n\x14_profile_picture_url\"\x90\x01\n\x13WorkspaceUserUpdate\x12.\n\x04role\x18\x01 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x00\x88\x01\x01\x12\x35\n\x06status\x18\x02 \x01(\tB \xfa\x42\x1dr\x1bR\x06\x61\x63tiveR\x07invitedR\x08\x64\x65\x63linedH\x01\x88\x01\x01\x42\x07\n\x05_roleB\t\n\x07_status\"\xd9\x01\n\x0fWorkspacePlugin\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12\x14\n\x07payload\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\ncreated_at\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x16\n\tis_public\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\x05\n\x03_idB\x0f\n\r_workspace_idB\n\n\x08_payloadB\r\n\x0b_created_atB\x0c\n\n_is_public\"_\n\x15WorkspacePluginUpdate\x12\x14\n\x07payload\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tis_public\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\n\n\x08_payloadB\x0c\n\n_is_public\"B\n\x14WorkspaceListRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\n\n\x08_user_id\"v\n\x15WorkspaceListResponse\x12(\n\nworkspaces\x18\x01 \x03(\x0b\x32\x14.workspace.Workspace\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"I\n\x1bInvitedWorkspaceListRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\n\n\x08_user_id\"}\n\x1cInvitedWorkspaceListResponse\x12(\n\nworkspaces\x18\x01 \x03(\x0b\x32\x14.workspace.Workspace\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x88\x01\n\x16WorkspaceCreateRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x34\n\tworkspace\x18\x02 \x01(\x0b\x32\x1c.workspace.WorkspaceCreationH\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0c\n\n_workspace\"\x8a\x01\n\x17WorkspaceCreateResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"w\n\x13WorkspaceGetRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"\x87\x01\n\x14WorkspaceGetResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"\x90\x01\n\x16WorkspaceUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x32\n\tworkspace\x18\x02 \x01(\x0b\x32\x1a.workspace.WorkspaceUpdateH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_workspace\"\x8a\x01\n\x17WorkspaceUpdateResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"z\n\x16WorkspaceDeleteRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"N\n\x17WorkspaceDeleteResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xca\x01\n\x1aWorkspaceInviteUserRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12\x1b\n\x07user_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x12\x18\n\x05\x65mail\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02`\x01H\x00\x12.\n\x04role\x18\x04 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x02\x88\x01\x01\x42\x06\n\x04userB\x0f\n\r_workspace_idB\x07\n\x05_role\"\x9c\x01\n\x1bWorkspaceInviteUserResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"P\n\x18WorkspaceUserListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x83\x01\n\x19WorkspaceUserListResponse\x12\x31\n\x0fworkspace_users\x18\x01 \x03(\x0b\x32\x18.workspace.WorkspaceUser\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"{\n\x17WorkspaceUserGetRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"\x99\x01\n\x18WorkspaceUserGetResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"\xce\x01\n\x1aWorkspaceUserUpdateRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12;\n\x0eworkspace_user\x18\x03 \x01(\x0b\x32\x1e.workspace.WorkspaceUserUpdateH\x02\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_idB\x11\n\x0f_workspace_user\"\x9c\x01\n\x1bWorkspaceUserUpdateResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"~\n\x1aWorkspaceUserDeleteRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"R\n\x1bWorkspaceUserDeleteResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x9c\x01\n\x1cWorkspacePluginCreateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x14\n\x07payload\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tis_public\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\x0f\n\r_workspace_idB\n\n\x08_payloadB\x0c\n\n_is_public\"\xa4\x01\n\x1dWorkspacePluginCreateResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"\x81\x01\n\x19WorkspacePluginGetRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_id\"\xa1\x01\n\x1aWorkspacePluginGetResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"R\n\x1aWorkspacePluginListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x89\x01\n\x1bWorkspacePluginListResponse\x12\x35\n\x11workspace_plugins\x18\x01 \x03(\x0b\x32\x1a.workspace.WorkspacePlugin\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xda\x01\n\x1cWorkspacePluginUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12?\n\x10workspace_plugin\x18\x03 \x01(\x0b\x32 .workspace.WorkspacePluginUpdateH\x02\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_idB\x13\n\x11_workspace_plugin\"\xa4\x01\n\x1dWorkspacePluginUpdateResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"\x84\x01\n\x1cWorkspacePluginDeleteRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_id\"T\n\x1dWorkspacePluginDeleteResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"L\n\x14WorkspaceWipeRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"L\n\x15WorkspaceWipeResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error2i\n\x10WorkspaceService\x12U\n\x08ListUser\x12#.workspace.WorkspaceUserListRequest\x1a$.workspace.WorkspaceUserListResponseB2Z0github.com/jupyter-naas/naas-models/go/workspaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workspace_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/jupyter-naas/naas-models/go/workspace'
  _globals['_WORKSPACE'].fields_by_name['id']._loaded_options = None
  _globals['_WORKSPACE'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACE'].fields_by_name['default_plugin_id']._loaded_options = None
  _globals['_WORKSPACE'].fields_by_name['default_plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUPDATE'].fields_by_name['default_plugin_id']._loaded_options = None
  _globals['_WORKSPACEUPDATE'].fields_by_name['default_plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSER'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSER'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSER'].fields_by_name['role']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _globals['_WORKSPACEUSER'].fields_by_name['status']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['status']._serialized_options = b'\372B\035r\033R\006activeR\007invitedR\010declined'
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['role']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['status']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['status']._serialized_options = b'\372B\035r\033R\006activeR\007invitedR\010declined'
  _globals['_WORKSPACEPLUGIN'].fields_by_name['id']._loaded_options = None
  _globals['_WORKSPACEPLUGIN'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGIN'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGIN'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACELISTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACELISTREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_INVITEDWORKSPACELISTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_INVITEDWORKSPACELISTREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACECREATEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACECREATEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['email']._loaded_options = None
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['email']._serialized_options = b'\372B\004r\002`\001'
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['role']._loaded_options = None
  _globals['_WORKSPACEINVITEUSERREQUEST'].fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _globals['_WORKSPACEUSERLISTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERLISTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINCREATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINCREATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINLISTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINLISTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEWIPEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEWIPEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACE']._serialized_start=61
  _globals['_WORKSPACE']._serialized_end=656
  _globals['_WORKSPACECREATION']._serialized_start=659
  _globals['_WORKSPACECREATION']._serialized_end=1124
  _globals['_WORKSPACEUPDATE']._serialized_start=1127
  _globals['_WORKSPACEUPDATE']._serialized_end=1612
  _globals['_WORKSPACEUSER']._serialized_start=1615
  _globals['_WORKSPACEUSER']._serialized_end=2093
  _globals['_WORKSPACEUSERUPDATE']._serialized_start=2096
  _globals['_WORKSPACEUSERUPDATE']._serialized_end=2240
  _globals['_WORKSPACEPLUGIN']._serialized_start=2243
  _globals['_WORKSPACEPLUGIN']._serialized_end=2460
  _globals['_WORKSPACEPLUGINUPDATE']._serialized_start=2462
  _globals['_WORKSPACEPLUGINUPDATE']._serialized_end=2557
  _globals['_WORKSPACELISTREQUEST']._serialized_start=2559
  _globals['_WORKSPACELISTREQUEST']._serialized_end=2625
  _globals['_WORKSPACELISTRESPONSE']._serialized_start=2627
  _globals['_WORKSPACELISTRESPONSE']._serialized_end=2745
  _globals['_INVITEDWORKSPACELISTREQUEST']._serialized_start=2747
  _globals['_INVITEDWORKSPACELISTREQUEST']._serialized_end=2820
  _globals['_INVITEDWORKSPACELISTRESPONSE']._serialized_start=2822
  _globals['_INVITEDWORKSPACELISTRESPONSE']._serialized_end=2947
  _globals['_WORKSPACECREATEREQUEST']._serialized_start=2950
  _globals['_WORKSPACECREATEREQUEST']._serialized_end=3086
  _globals['_WORKSPACECREATERESPONSE']._serialized_start=3089
  _globals['_WORKSPACECREATERESPONSE']._serialized_end=3227
  _globals['_WORKSPACEGETREQUEST']._serialized_start=3229
  _globals['_WORKSPACEGETREQUEST']._serialized_end=3348
  _globals['_WORKSPACEGETRESPONSE']._serialized_start=3351
  _globals['_WORKSPACEGETRESPONSE']._serialized_end=3486
  _globals['_WORKSPACEUPDATEREQUEST']._serialized_start=3489
  _globals['_WORKSPACEUPDATEREQUEST']._serialized_end=3633
  _globals['_WORKSPACEUPDATERESPONSE']._serialized_start=3636
  _globals['_WORKSPACEUPDATERESPONSE']._serialized_end=3774
  _globals['_WORKSPACEDELETEREQUEST']._serialized_start=3776
  _globals['_WORKSPACEDELETEREQUEST']._serialized_end=3898
  _globals['_WORKSPACEDELETERESPONSE']._serialized_start=3900
  _globals['_WORKSPACEDELETERESPONSE']._serialized_end=3978
  _globals['_WORKSPACEINVITEUSERREQUEST']._serialized_start=3981
  _globals['_WORKSPACEINVITEUSERREQUEST']._serialized_end=4183
  _globals['_WORKSPACEINVITEUSERRESPONSE']._serialized_start=4186
  _globals['_WORKSPACEINVITEUSERRESPONSE']._serialized_end=4342
  _globals['_WORKSPACEUSERLISTREQUEST']._serialized_start=4344
  _globals['_WORKSPACEUSERLISTREQUEST']._serialized_end=4424
  _globals['_WORKSPACEUSERLISTRESPONSE']._serialized_start=4427
  _globals['_WORKSPACEUSERLISTRESPONSE']._serialized_end=4558
  _globals['_WORKSPACEUSERGETREQUEST']._serialized_start=4560
  _globals['_WORKSPACEUSERGETREQUEST']._serialized_end=4683
  _globals['_WORKSPACEUSERGETRESPONSE']._serialized_start=4686
  _globals['_WORKSPACEUSERGETRESPONSE']._serialized_end=4839
  _globals['_WORKSPACEUSERUPDATEREQUEST']._serialized_start=4842
  _globals['_WORKSPACEUSERUPDATEREQUEST']._serialized_end=5048
  _globals['_WORKSPACEUSERUPDATERESPONSE']._serialized_start=5051
  _globals['_WORKSPACEUSERUPDATERESPONSE']._serialized_end=5207
  _globals['_WORKSPACEUSERDELETEREQUEST']._serialized_start=5209
  _globals['_WORKSPACEUSERDELETEREQUEST']._serialized_end=5335
  _globals['_WORKSPACEUSERDELETERESPONSE']._serialized_start=5337
  _globals['_WORKSPACEUSERDELETERESPONSE']._serialized_end=5419
  _globals['_WORKSPACEPLUGINCREATEREQUEST']._serialized_start=5422
  _globals['_WORKSPACEPLUGINCREATEREQUEST']._serialized_end=5578
  _globals['_WORKSPACEPLUGINCREATERESPONSE']._serialized_start=5581
  _globals['_WORKSPACEPLUGINCREATERESPONSE']._serialized_end=5745
  _globals['_WORKSPACEPLUGINGETREQUEST']._serialized_start=5748
  _globals['_WORKSPACEPLUGINGETREQUEST']._serialized_end=5877
  _globals['_WORKSPACEPLUGINGETRESPONSE']._serialized_start=5880
  _globals['_WORKSPACEPLUGINGETRESPONSE']._serialized_end=6041
  _globals['_WORKSPACEPLUGINLISTREQUEST']._serialized_start=6043
  _globals['_WORKSPACEPLUGINLISTREQUEST']._serialized_end=6125
  _globals['_WORKSPACEPLUGINLISTRESPONSE']._serialized_start=6128
  _globals['_WORKSPACEPLUGINLISTRESPONSE']._serialized_end=6265
  _globals['_WORKSPACEPLUGINUPDATEREQUEST']._serialized_start=6268
  _globals['_WORKSPACEPLUGINUPDATEREQUEST']._serialized_end=6486
  _globals['_WORKSPACEPLUGINUPDATERESPONSE']._serialized_start=6489
  _globals['_WORKSPACEPLUGINUPDATERESPONSE']._serialized_end=6653
  _globals['_WORKSPACEPLUGINDELETEREQUEST']._serialized_start=6656
  _globals['_WORKSPACEPLUGINDELETEREQUEST']._serialized_end=6788
  _globals['_WORKSPACEPLUGINDELETERESPONSE']._serialized_start=6790
  _globals['_WORKSPACEPLUGINDELETERESPONSE']._serialized_end=6874
  _globals['_WORKSPACEWIPEREQUEST']._serialized_start=6876
  _globals['_WORKSPACEWIPEREQUEST']._serialized_end=6952
  _globals['_WORKSPACEWIPERESPONSE']._serialized_start=6954
  _globals['_WORKSPACEWIPERESPONSE']._serialized_end=7030
  _globals['_WORKSPACESERVICE']._serialized_start=7032
  _globals['_WORKSPACESERVICE']._serialized_end=7137
# @@protoc_insertion_point(module_scope)



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.3.3.1](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.12.3 
from .common_p2p import FieldMask
from .errors_p2p import ErrorResponse
from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic import ConfigDict
from pydantic import Field
from uuid import UUID
import typing

class MessageType(IntEnum):
    UNDEFINED = 0
    SYSTEM = 1
    AI = 2
    HUMAN = 3
    TOOL_USAGE = 5
    TOOL_ANSWER = 6


class MessageStatus(IntEnum):
    MESSAGE_STATUS_UNSPECIFIED = 0
    MESSAGE_STATUS_PENDING = 1
    MESSAGE_STATUS_COMPLETED = 2
    MESSAGE_STATUS_FAILED = 3
    MESSAGE_STATUS_CANCELLED = 4


class CompletionStatus(IntEnum):
    COMPLETED = 0
    FAILED = 1
    TIMEOUT = 2

class Message(BaseModel):
    model_config = ConfigDict(validate_default=True)
    id: typing.Optional[int] = Field(default=0)
    version: typing.Optional[int] = Field(default=0)
    created_at: typing.Optional[str] = Field(default="")
    chat_id: typing.Optional[int] = Field(default=0)
    from_user: typing.Optional[bool] = Field(default=False)
    message: typing.Optional[str] = Field(default="")
    message_type: typing.Optional[str] = Field(default="")
    message_language: typing.Optional[str] = Field(default="")
    model_id: typing.Optional[str] = Field(default="")
    type: typing.Optional[MessageType] = Field(default=0)
    metadata: typing.Optional[str] = Field(default="")
    deleted_at: typing.Optional[str] = Field(default="")
    selected: typing.Optional[bool] = Field(default=False)
    archived_at: typing.Optional[str] = Field(default="")
    status: typing.Optional[MessageStatus] = Field(default=0)

class MessageUpdate(BaseModel):
    message: typing.Optional[str] = Field(default="")
    message_type: typing.Optional[str] = Field(default="")
    message_language: typing.Optional[str] = Field(default="")
    metadata: typing.Optional[str] = Field(default="")
    selected: typing.Optional[bool] = Field(default=False)
    archived_at: typing.Optional[str] = Field(default="")
    field_mask: typing.Optional[FieldMask] = Field(default_factory=FieldMask)

class Messages(BaseModel):
    messages: typing.List[Message] = Field(default_factory=list)

class MessageDeletionRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0)
    version: typing.Optional[int] = Field(default=0)

class MessageDeletionResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class MessageRating(BaseModel):
    message_id: typing.Optional[int] = Field(default=0)
    user_id: typing.Optional[str] = Field(default="")
    message_version: typing.Optional[int] = Field(default=0)
    created_at: typing.Optional[str] = Field(default="")
    rating: typing.Optional[str] = Field(default="", pattern="^(LIKE|DISLIKE)$")

class MessageRatingCreationRequest(BaseModel):
    message_id: typing.Optional[int] = Field(default=0)
    message_version: typing.Optional[int] = Field(default=0)
    rating: typing.Optional[str] = Field(default="", pattern="^(LIKE|DISLIKE)$")

class MessageRatingCreationResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)
    message_rating: typing.Optional[MessageRating] = Field(default_factory=MessageRating)

class Chat(BaseModel):
    id: typing.Optional[int] = Field(default=0)
    created_at: typing.Optional[str] = Field(default="")
    user_id: typing.Optional[str] = Field(default="")
    name: typing.Optional[str] = Field(default="")
    deleted_at: typing.Optional[str] = Field(default="")
    is_group: typing.Optional[bool] = Field(default=False)
    starred_at: typing.Optional[str] = Field(default="")
    workspace_id: typing.Optional[UUID] = Field(default="")

class ChatUpdate(BaseModel):
    name: typing.Optional[str] = Field(default="")
    is_group: typing.Optional[bool] = Field(default=False)
    starred_at: typing.Optional[str] = Field(default="")
    field_mask: typing.Optional[FieldMask] = Field(default_factory=FieldMask)

class ChatMessages(BaseModel):
    messages: "typing.Dict[int, Messages]" = Field(default_factory=dict)

class ChatCreationRequest(BaseModel):
    name: typing.Optional[str] = Field(default="")
    workspace_id: typing.Optional[UUID] = Field(default="")

class ChatCreationResponse(BaseModel):
    chat: typing.Optional[Chat] = Field(default_factory=Chat)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class ChatGetRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0)

class ChatGetResponse(BaseModel):
    chat: typing.Optional[Chat] = Field(default_factory=Chat)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class ChatMessageGetRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0)

class ChatMessageGetResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)
    messages: typing.Optional[ChatMessages] = Field(default_factory=ChatMessages)

class ChatDeletionRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0)

class ChatDeletionResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class ChatUpdateRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0)
    chat_update: typing.Optional[ChatUpdate] = Field(default_factory=ChatUpdate)

class ChatUpdateResponse(BaseModel):
    chat: typing.Optional[Chat] = Field(default_factory=Chat)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class ChatListRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="")

class ChatListResponse(BaseModel):
    chat: typing.List[Chat] = Field(default_factory=list)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class ChatStarRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0)
    star: typing.Optional[bool] = Field(default=False)

class ChatStarResponse(BaseModel):
    chat: typing.Optional[Chat] = Field(default_factory=Chat)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class ChatArchiveRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0)

class ChatArchiveResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class CompletionResponse(BaseModel):
    model_config = ConfigDict(validate_default=True)
    messages: typing.List[Message] = Field(default_factory=list)
    input_tokens: typing.Optional[int] = Field(default=0)
    output_tokens: typing.Optional[int] = Field(default=0)
    image_resolution: typing.Optional[str] = Field(default="")
    image_steps: typing.Optional[int] = Field(default=0)
    status: typing.Optional[CompletionStatus] = Field(default=0)

class BasePayload(BaseModel):
    name: typing.Optional[str] = Field(default="")
    url: typing.Optional[str] = Field(default="")
    prompt: typing.Optional[str] = Field(default="")#optional string commands = 4;

class ChatCompletionRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0)
    model_id: typing.Optional[str] = Field(default="")
    payload: typing.Optional[str] = Field(default="")
    plugin_id: typing.Optional[UUID] = Field(default="")

class ChatStopCompletionRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0)

class ChatStopCompletionResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class ChatCompletionResponse(BaseModel):
    completion: typing.Optional[CompletionResponse] = Field(default_factory=CompletionResponse)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.3.3.1](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.12.3 
from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.field_info_rule.protobuf_option_to_field_info.types import UriRefStr
from pydantic import BaseModel
from pydantic import ConfigDict
from pydantic import Field
from uuid import UUID
import typing

class SpaceError(IntEnum):
    SPACE_NO_ERROR = 0
    SPACE_ALREADY_EXISTS = 1
    SPACE_NOT_FOUND = 2
    SPACE_NOT_UPDATED = 3
    SPACE_MUST_HAVE_ONE_CONTAINER_PORT = 4
    SPACE_SUBSCRIPTION_REQUIRED = 5

class Container(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9-]+)$")
    image: typing.Optional[str] = Field(default="", min_length=1, pattern="^[a-zA-Z0-9\\.\\/-]+([:@][a-zA-Z0-9\\.\\/:_-]*)?$")
    env: "typing.Dict[str, str]" = Field(default_factory=dict)
    port: typing.Optional[int] = Field(default=0, ge=0, le=65535)
    cpu: typing.Optional[str] = Field(default="", pattern="^[1-9]+(.[1-9]+)?[m]?$")
    memory: typing.Optional[str] = Field(default="", pattern="^[1-9]+(Mi|Gi|Ki)$")

class ContainerUpdate(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9-]+)$")
    image: typing.Optional[str] = Field(default="", min_length=1, pattern="^[a-zA-Z0-9\\.\\/-]+([:@][a-zA-Z0-9\\.\\/:_-]*)?$")
    env: "typing.Dict[str, str]" = Field(default_factory=dict)
    port: typing.Optional[int] = Field(default=0, ge=0, le=65535)
    cpu: typing.Optional[str] = Field(default="", pattern="^[1-9]+(.[1-9]+)?[m]?$")
    memory: typing.Optional[str] = Field(default="", pattern="^[1-9]+(Mi|Gi|Ki)$")

class Space(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$")
    user_id: typing.Optional[UUID] = Field(default="")
    id: typing.Optional[UUID] = Field(default="")
    domain: typing.Optional[UriRefStr] = Field(default="")
    containers: typing.List[Container] = Field(default_factory=list, min_length=1)

class SpaceUpdate(BaseModel):
    domain: typing.Optional[UriRefStr] = Field(default="")
    containers: typing.List[ContainerUpdate] = Field(default_factory=list, min_length=1)

class SpaceResponseError(BaseModel):
    model_config = ConfigDict(validate_default=True)
    code: typing.Optional[SpaceError] = Field(default=0)
    status: typing.Optional[str] = Field(default="")
    reason: typing.Optional[str] = Field(default="")
    message: typing.Optional[str] = Field(default="")

class SpaceCreationRequest(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$")
    domain: typing.Optional[UriRefStr] = Field(default="")
    containers: typing.List[Container] = Field(default_factory=list, min_length=1)

class SpaceCreationResponse(BaseModel):
    space: typing.Optional[Space] = Field(default_factory=Space)
    status: typing.Optional[str] = Field(default="")

class SpaceGetRequest(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$")

class SpaceGetResponse(BaseModel):
    space: typing.Optional[Space] = Field(default_factory=Space)
    status: typing.Optional[str] = Field(default="")

class SpaceDeletionRequest(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$")

class SpaceDeletionResponse(BaseModel):
    status: typing.Optional[str] = Field(default="")

class SpaceListRequest(BaseModel):
    page_size: typing.Optional[int] = Field(default=0)
    page_number: typing.Optional[int] = Field(default=0)

class SpaceListResponse(BaseModel):
    spaces: typing.List[Space] = Field(default_factory=list)

class SpaceUpdateRequest(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$")
    space: typing.Optional[SpaceUpdate] = Field(default_factory=SpaceUpdate)# optional string domain = 4 [(validate.rules).string.uri_ref = true];
#repeated ContainerUpdate containers = 2 [(validate.rules).repeated.min_items = 1];

class SpaceUpdateResponse(BaseModel):
    space: typing.Optional[Space] = Field(default_factory=Space)
    status: typing.Optional[str] = Field(default="")



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.3.3.1](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.12.3 
from .errors_p2p import ErrorResponse
from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.customer_validator import check_one_of
from protobuf_to_pydantic.customer_validator.v2 import in_validator
from pydantic import BaseModel
from pydantic import Field
from pydantic import field_validator
from pydantic import model_validator
from pydantic.networks import EmailStr
from uuid import UUID
import typing


class Workspace(BaseModel):
    id: typing.Optional[UUID] = Field(default="")
    name: typing.Optional[str] = Field(default="")
    fav_icon: typing.Optional[str] = Field(default="")
    large_logo: typing.Optional[str] = Field(default="")
    small_logo: typing.Optional[str] = Field(default="")
    primary_color: typing.Optional[str] = Field(default="")
    secondary_color: typing.Optional[str] = Field(default="")
    tertiary_color: typing.Optional[str] = Field(default="")
    text_primary_color: typing.Optional[str] = Field(default="")
    text_secondary_color: typing.Optional[str] = Field(default="")
    is_personal: typing.Optional[bool] = Field(default=False)
    created_at: typing.Optional[str] = Field(default="")
    default_plugin_id: typing.Optional[UUID] = Field(default="")

class WorkspaceCreation(BaseModel):
    name: typing.Optional[str] = Field(default="")
    fav_icon: typing.Optional[str] = Field(default="")
    large_logo: typing.Optional[str] = Field(default="")
    small_logo: typing.Optional[str] = Field(default="")
    primary_color: typing.Optional[str] = Field(default="")
    secondary_color: typing.Optional[str] = Field(default="")
    tertiary_color: typing.Optional[str] = Field(default="")
    text_primary_color: typing.Optional[str] = Field(default="")
    text_secondary_color: typing.Optional[str] = Field(default="")
    is_personal: typing.Optional[bool] = Field(default=False)

class WorkspaceUpdate(BaseModel):
    name: typing.Optional[str] = Field(default="")
    fav_icon: typing.Optional[str] = Field(default="")
    large_logo: typing.Optional[str] = Field(default="")
    small_logo: typing.Optional[str] = Field(default="")
    primary_color: typing.Optional[str] = Field(default="")
    secondary_color: typing.Optional[str] = Field(default="")
    tertiary_color: typing.Optional[str] = Field(default="")
    text_primary_color: typing.Optional[str] = Field(default="")
    text_secondary_color: typing.Optional[str] = Field(default="")
    default_plugin_id: typing.Optional[UUID] = Field(default="")

class WorkspaceUser(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="")
    workspace_id: typing.Optional[UUID] = Field(default="")
    role: typing.Optional[str] = Field(default="", in_=["owner", "admin", "member"])
    status: typing.Optional[str] = Field(default="", in_=["active", "invited", "declined"])
    create_at: typing.Optional[str] = Field(default="")
    update_at: typing.Optional[str] = Field(default="")
    first_name: typing.Optional[str] = Field(default="")
    last_name: typing.Optional[str] = Field(default="")
    email: typing.Optional[str] = Field(default="")
    profile_picture_url: typing.Optional[str] = Field(default="")

    role_in_validator = field_validator("role", mode="after",check_fields=None)(in_validator)
    status_in_validator = field_validator("status", mode="after",check_fields=None)(in_validator)

class WorkspaceUserUpdate(BaseModel):
    role: typing.Optional[str] = Field(default="", in_=["owner", "admin", "member"])
    status: typing.Optional[str] = Field(default="", in_=["active", "invited", "declined"])

    role_in_validator = field_validator("role", mode="after",check_fields=None)(in_validator)
    status_in_validator = field_validator("status", mode="after",check_fields=None)(in_validator)

class WorkspacePlugin(BaseModel):
    id: typing.Optional[UUID] = Field(default="")
    workspace_id: typing.Optional[UUID] = Field(default="")
    payload: typing.Optional[str] = Field(default="")
    created_at: typing.Optional[str] = Field(default="")
    is_public: typing.Optional[bool] = Field(default=False)

class WorkspacePluginUpdate(BaseModel):
    payload: typing.Optional[str] = Field(default="")
    is_public: typing.Optional[bool] = Field(default=False)

class WorkspaceListRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="")

class WorkspaceListResponse(BaseModel):
    workspaces: typing.List[Workspace] = Field(default_factory=list)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class InvitedWorkspaceListRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="")

class InvitedWorkspaceListResponse(BaseModel):
    workspaces: typing.List[Workspace] = Field(default_factory=list)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspaceCreateRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="")
    workspace: typing.Optional[WorkspaceCreation] = Field(default_factory=WorkspaceCreation)

class WorkspaceCreateResponse(BaseModel):
    workspace: typing.Optional[Workspace] = Field(default_factory=Workspace)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspaceGetRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="")
    workspace_id: typing.Optional[UUID] = Field(default="")

class WorkspaceGetResponse(BaseModel):
    workspace: typing.Optional[Workspace] = Field(default_factory=Workspace)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspaceUpdateRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="")
    workspace: typing.Optional[WorkspaceUpdate] = Field(default_factory=WorkspaceUpdate)

class WorkspaceUpdateResponse(BaseModel):
    workspace: typing.Optional[Workspace] = Field(default_factory=Workspace)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspaceDeleteRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="")
    workspace_id: typing.Optional[UUID] = Field(default="")

class WorkspaceDeleteResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspaceInviteUserRequest(BaseModel):
    _one_of_dict = {"WorkspaceInviteUserRequest.user": {"fields": {"email", "user_id"}}}
    one_of_validator = model_validator(mode="before")(check_one_of)
    workspace_id: typing.Optional[UUID] = Field(default="")
    user_id: UUID = Field(default="")
    email: EmailStr = Field(default="")
    role: typing.Optional[str] = Field(default="", in_=["owner", "admin", "member"])

    role_in_validator = field_validator("role", mode="after",check_fields=None)(in_validator)

class WorkspaceInviteUserResponse(BaseModel):
    workspace_user: typing.Optional[WorkspaceUser] = Field(default_factory=WorkspaceUser)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspaceUserListRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="")

class WorkspaceUserListResponse(BaseModel):
    workspace_users: typing.List[WorkspaceUser] = Field(default_factory=list)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspaceUserGetRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="")
    workspace_id: typing.Optional[UUID] = Field(default="")

class WorkspaceUserGetResponse(BaseModel):
    workspace_user: typing.Optional[WorkspaceUser] = Field(default_factory=WorkspaceUser)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspaceUserUpdateRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="")
    workspace_id: typing.Optional[UUID] = Field(default="")
    workspace_user: typing.Optional[WorkspaceUserUpdate] = Field(default_factory=WorkspaceUserUpdate)

class WorkspaceUserUpdateResponse(BaseModel):
    workspace_user: typing.Optional[WorkspaceUser] = Field(default_factory=WorkspaceUser)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspaceUserDeleteRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="")
    workspace_id: typing.Optional[UUID] = Field(default="")

class WorkspaceUserDeleteResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspacePluginCreateRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="")
    payload: typing.Optional[str] = Field(default="")
    is_public: typing.Optional[bool] = Field(default=False)

class WorkspacePluginCreateResponse(BaseModel):
    workspace_plugin: typing.Optional[WorkspacePlugin] = Field(default_factory=WorkspacePlugin)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspacePluginGetRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="")
    plugin_id: typing.Optional[UUID] = Field(default="")

class WorkspacePluginGetResponse(BaseModel):
    workspace_plugin: typing.Optional[WorkspacePlugin] = Field(default_factory=WorkspacePlugin)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspacePluginListRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="")

class WorkspacePluginListResponse(BaseModel):
    workspace_plugins: typing.List[WorkspacePlugin] = Field(default_factory=list)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspacePluginUpdateRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="")
    plugin_id: typing.Optional[UUID] = Field(default="")
    workspace_plugin: typing.Optional[WorkspacePluginUpdate] = Field(default_factory=WorkspacePluginUpdate)

class WorkspacePluginUpdateResponse(BaseModel):
    workspace_plugin: typing.Optional[WorkspacePlugin] = Field(default_factory=WorkspacePlugin)
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspacePluginDeleteRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="")
    plugin_id: typing.Optional[UUID] = Field(default="")

class WorkspacePluginDeleteResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)

class WorkspaceWipeRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="")

class WorkspaceWipeResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default_factory=ErrorResponse)



import validate_pb2 as _validate_pb2
import errors_pb2 as _errors_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Workspace(_message.Message):
    __slots__ = ("id", "name", "fav_icon", "large_logo", "small_logo", "primary_color", "secondary_color", "tertiary_color", "text_primary_color", "text_secondary_color", "is_personal", "created_at", "default_plugin_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    FAV_ICON_FIELD_NUMBER: _ClassVar[int]
    LARGE_LOGO_FIELD_NUMBER: _ClassVar[int]
    SMALL_LOGO_FIELD_NUMBER: _ClassVar[int]
    PRIMARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    SECONDARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    TERTIARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    TEXT_PRIMARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    TEXT_SECONDARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    IS_PERSONAL_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_PLUGIN_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    fav_icon: str
    large_logo: str
    small_logo: str
    primary_color: str
    secondary_color: str
    tertiary_color: str
    text_primary_color: str
    text_secondary_color: str
    is_personal: bool
    created_at: str
    default_plugin_id: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., fav_icon: _Optional[str] = ..., large_logo: _Optional[str] = ..., small_logo: _Optional[str] = ..., primary_color: _Optional[str] = ..., secondary_color: _Optional[str] = ..., tertiary_color: _Optional[str] = ..., text_primary_color: _Optional[str] = ..., text_secondary_color: _Optional[str] = ..., is_personal: bool = ..., created_at: _Optional[str] = ..., default_plugin_id: _Optional[str] = ...) -> None: ...

class WorkspaceCreation(_message.Message):
    __slots__ = ("name", "fav_icon", "large_logo", "small_logo", "primary_color", "secondary_color", "tertiary_color", "text_primary_color", "text_secondary_color", "is_personal")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FAV_ICON_FIELD_NUMBER: _ClassVar[int]
    LARGE_LOGO_FIELD_NUMBER: _ClassVar[int]
    SMALL_LOGO_FIELD_NUMBER: _ClassVar[int]
    PRIMARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    SECONDARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    TERTIARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    TEXT_PRIMARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    TEXT_SECONDARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    IS_PERSONAL_FIELD_NUMBER: _ClassVar[int]
    name: str
    fav_icon: str
    large_logo: str
    small_logo: str
    primary_color: str
    secondary_color: str
    tertiary_color: str
    text_primary_color: str
    text_secondary_color: str
    is_personal: bool
    def __init__(self, name: _Optional[str] = ..., fav_icon: _Optional[str] = ..., large_logo: _Optional[str] = ..., small_logo: _Optional[str] = ..., primary_color: _Optional[str] = ..., secondary_color: _Optional[str] = ..., tertiary_color: _Optional[str] = ..., text_primary_color: _Optional[str] = ..., text_secondary_color: _Optional[str] = ..., is_personal: bool = ...) -> None: ...

class WorkspaceUpdate(_message.Message):
    __slots__ = ("name", "fav_icon", "large_logo", "small_logo", "primary_color", "secondary_color", "tertiary_color", "text_primary_color", "text_secondary_color", "default_plugin_id")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FAV_ICON_FIELD_NUMBER: _ClassVar[int]
    LARGE_LOGO_FIELD_NUMBER: _ClassVar[int]
    SMALL_LOGO_FIELD_NUMBER: _ClassVar[int]
    PRIMARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    SECONDARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    TERTIARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    TEXT_PRIMARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    TEXT_SECONDARY_COLOR_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_PLUGIN_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    fav_icon: str
    large_logo: str
    small_logo: str
    primary_color: str
    secondary_color: str
    tertiary_color: str
    text_primary_color: str
    text_secondary_color: str
    default_plugin_id: str
    def __init__(self, name: _Optional[str] = ..., fav_icon: _Optional[str] = ..., large_logo: _Optional[str] = ..., small_logo: _Optional[str] = ..., primary_color: _Optional[str] = ..., secondary_color: _Optional[str] = ..., tertiary_color: _Optional[str] = ..., text_primary_color: _Optional[str] = ..., text_secondary_color: _Optional[str] = ..., default_plugin_id: _Optional[str] = ...) -> None: ...

class WorkspaceUser(_message.Message):
    __slots__ = ("user_id", "workspace_id", "role", "status", "create_at", "update_at", "first_name", "last_name", "email", "profile_picture_url")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATE_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATE_AT_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    PROFILE_PICTURE_URL_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    workspace_id: str
    role: str
    status: str
    create_at: str
    update_at: str
    first_name: str
    last_name: str
    email: str
    profile_picture_url: str
    def __init__(self, user_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., role: _Optional[str] = ..., status: _Optional[str] = ..., create_at: _Optional[str] = ..., update_at: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., email: _Optional[str] = ..., profile_picture_url: _Optional[str] = ...) -> None: ...

class WorkspaceUserUpdate(_message.Message):
    __slots__ = ("role", "status")
    ROLE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    role: str
    status: str
    def __init__(self, role: _Optional[str] = ..., status: _Optional[str] = ...) -> None: ...

class WorkspacePlugin(_message.Message):
    __slots__ = ("id", "workspace_id", "payload", "created_at", "is_public")
    ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    id: str
    workspace_id: str
    payload: str
    created_at: str
    is_public: bool
    def __init__(self, id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., payload: _Optional[str] = ..., created_at: _Optional[str] = ..., is_public: bool = ...) -> None: ...

class WorkspacePluginUpdate(_message.Message):
    __slots__ = ("payload", "is_public")
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    payload: str
    is_public: bool
    def __init__(self, payload: _Optional[str] = ..., is_public: bool = ...) -> None: ...

class WorkspaceListRequest(_message.Message):
    __slots__ = ("user_id",)
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class WorkspaceListResponse(_message.Message):
    __slots__ = ("workspaces", "error")
    WORKSPACES_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspaces: _containers.RepeatedCompositeFieldContainer[Workspace]
    error: _errors_pb2.ErrorResponse
    def __init__(self, workspaces: _Optional[_Iterable[_Union[Workspace, _Mapping]]] = ..., error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class InvitedWorkspaceListRequest(_message.Message):
    __slots__ = ("user_id",)
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class InvitedWorkspaceListResponse(_message.Message):
    __slots__ = ("workspaces", "error")
    WORKSPACES_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspaces: _containers.RepeatedCompositeFieldContainer[Workspace]
    error: _errors_pb2.ErrorResponse
    def __init__(self, workspaces: _Optional[_Iterable[_Union[Workspace, _Mapping]]] = ..., error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspaceCreateRequest(_message.Message):
    __slots__ = ("user_id", "workspace")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    workspace: WorkspaceCreation
    def __init__(self, user_id: _Optional[str] = ..., workspace: _Optional[_Union[WorkspaceCreation, _Mapping]] = ...) -> None: ...

class WorkspaceCreateResponse(_message.Message):
    __slots__ = ("workspace", "error")
    WORKSPACE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspace: Workspace
    error: _errors_pb2.ErrorResponse
    def __init__(self, workspace: _Optional[_Union[Workspace, _Mapping]] = ..., error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspaceGetRequest(_message.Message):
    __slots__ = ("user_id", "workspace_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    workspace_id: str
    def __init__(self, user_id: _Optional[str] = ..., workspace_id: _Optional[str] = ...) -> None: ...

class WorkspaceGetResponse(_message.Message):
    __slots__ = ("workspace", "error")
    WORKSPACE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspace: Workspace
    error: _errors_pb2.ErrorResponse
    def __init__(self, workspace: _Optional[_Union[Workspace, _Mapping]] = ..., error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspaceUpdateRequest(_message.Message):
    __slots__ = ("workspace_id", "workspace")
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_FIELD_NUMBER: _ClassVar[int]
    workspace_id: str
    workspace: WorkspaceUpdate
    def __init__(self, workspace_id: _Optional[str] = ..., workspace: _Optional[_Union[WorkspaceUpdate, _Mapping]] = ...) -> None: ...

class WorkspaceUpdateResponse(_message.Message):
    __slots__ = ("workspace", "error")
    WORKSPACE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspace: Workspace
    error: _errors_pb2.ErrorResponse
    def __init__(self, workspace: _Optional[_Union[Workspace, _Mapping]] = ..., error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspaceDeleteRequest(_message.Message):
    __slots__ = ("user_id", "workspace_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    workspace_id: str
    def __init__(self, user_id: _Optional[str] = ..., workspace_id: _Optional[str] = ...) -> None: ...

class WorkspaceDeleteResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: _errors_pb2.ErrorResponse
    def __init__(self, error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspaceInviteUserRequest(_message.Message):
    __slots__ = ("workspace_id", "user_id", "email", "role")
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    workspace_id: str
    user_id: str
    email: str
    role: str
    def __init__(self, workspace_id: _Optional[str] = ..., user_id: _Optional[str] = ..., email: _Optional[str] = ..., role: _Optional[str] = ...) -> None: ...

class WorkspaceInviteUserResponse(_message.Message):
    __slots__ = ("workspace_user", "error")
    WORKSPACE_USER_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspace_user: WorkspaceUser
    error: _errors_pb2.ErrorResponse
    def __init__(self, workspace_user: _Optional[_Union[WorkspaceUser, _Mapping]] = ..., error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspaceUserListRequest(_message.Message):
    __slots__ = ("workspace_id",)
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    workspace_id: str
    def __init__(self, workspace_id: _Optional[str] = ...) -> None: ...

class WorkspaceUserListResponse(_message.Message):
    __slots__ = ("workspace_users", "error")
    WORKSPACE_USERS_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspace_users: _containers.RepeatedCompositeFieldContainer[WorkspaceUser]
    error: _errors_pb2.ErrorResponse
    def __init__(self, workspace_users: _Optional[_Iterable[_Union[WorkspaceUser, _Mapping]]] = ..., error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspaceUserGetRequest(_message.Message):
    __slots__ = ("user_id", "workspace_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    workspace_id: str
    def __init__(self, user_id: _Optional[str] = ..., workspace_id: _Optional[str] = ...) -> None: ...

class WorkspaceUserGetResponse(_message.Message):
    __slots__ = ("workspace_user", "error")
    WORKSPACE_USER_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspace_user: WorkspaceUser
    error: _errors_pb2.ErrorResponse
    def __init__(self, workspace_user: _Optional[_Union[WorkspaceUser, _Mapping]] = ..., error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspaceUserUpdateRequest(_message.Message):
    __slots__ = ("user_id", "workspace_id", "workspace_user")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_USER_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    workspace_id: str
    workspace_user: WorkspaceUserUpdate
    def __init__(self, user_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., workspace_user: _Optional[_Union[WorkspaceUserUpdate, _Mapping]] = ...) -> None: ...

class WorkspaceUserUpdateResponse(_message.Message):
    __slots__ = ("workspace_user", "error")
    WORKSPACE_USER_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspace_user: WorkspaceUser
    error: _errors_pb2.ErrorResponse
    def __init__(self, workspace_user: _Optional[_Union[WorkspaceUser, _Mapping]] = ..., error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspaceUserDeleteRequest(_message.Message):
    __slots__ = ("user_id", "workspace_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    workspace_id: str
    def __init__(self, user_id: _Optional[str] = ..., workspace_id: _Optional[str] = ...) -> None: ...

class WorkspaceUserDeleteResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: _errors_pb2.ErrorResponse
    def __init__(self, error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspacePluginCreateRequest(_message.Message):
    __slots__ = ("workspace_id", "payload", "is_public")
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    workspace_id: str
    payload: str
    is_public: bool
    def __init__(self, workspace_id: _Optional[str] = ..., payload: _Optional[str] = ..., is_public: bool = ...) -> None: ...

class WorkspacePluginCreateResponse(_message.Message):
    __slots__ = ("workspace_plugin", "error")
    WORKSPACE_PLUGIN_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspace_plugin: WorkspacePlugin
    error: _errors_pb2.ErrorResponse
    def __init__(self, workspace_plugin: _Optional[_Union[WorkspacePlugin, _Mapping]] = ..., error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspacePluginGetRequest(_message.Message):
    __slots__ = ("workspace_id", "plugin_id")
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    PLUGIN_ID_FIELD_NUMBER: _ClassVar[int]
    workspace_id: str
    plugin_id: str
    def __init__(self, workspace_id: _Optional[str] = ..., plugin_id: _Optional[str] = ...) -> None: ...

class WorkspacePluginGetResponse(_message.Message):
    __slots__ = ("workspace_plugin", "error")
    WORKSPACE_PLUGIN_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspace_plugin: WorkspacePlugin
    error: _errors_pb2.ErrorResponse
    def __init__(self, workspace_plugin: _Optional[_Union[WorkspacePlugin, _Mapping]] = ..., error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspacePluginListRequest(_message.Message):
    __slots__ = ("workspace_id",)
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    workspace_id: str
    def __init__(self, workspace_id: _Optional[str] = ...) -> None: ...

class WorkspacePluginListResponse(_message.Message):
    __slots__ = ("workspace_plugins", "error")
    WORKSPACE_PLUGINS_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspace_plugins: _containers.RepeatedCompositeFieldContainer[WorkspacePlugin]
    error: _errors_pb2.ErrorResponse
    def __init__(self, workspace_plugins: _Optional[_Iterable[_Union[WorkspacePlugin, _Mapping]]] = ..., error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspacePluginUpdateRequest(_message.Message):
    __slots__ = ("workspace_id", "plugin_id", "workspace_plugin")
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    PLUGIN_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_PLUGIN_FIELD_NUMBER: _ClassVar[int]
    workspace_id: str
    plugin_id: str
    workspace_plugin: WorkspacePluginUpdate
    def __init__(self, workspace_id: _Optional[str] = ..., plugin_id: _Optional[str] = ..., workspace_plugin: _Optional[_Union[WorkspacePluginUpdate, _Mapping]] = ...) -> None: ...

class WorkspacePluginUpdateResponse(_message.Message):
    __slots__ = ("workspace_plugin", "error")
    WORKSPACE_PLUGIN_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    workspace_plugin: WorkspacePlugin
    error: _errors_pb2.ErrorResponse
    def __init__(self, workspace_plugin: _Optional[_Union[WorkspacePlugin, _Mapping]] = ..., error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspacePluginDeleteRequest(_message.Message):
    __slots__ = ("workspace_id", "plugin_id")
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    PLUGIN_ID_FIELD_NUMBER: _ClassVar[int]
    workspace_id: str
    plugin_id: str
    def __init__(self, workspace_id: _Optional[str] = ..., plugin_id: _Optional[str] = ...) -> None: ...

class WorkspacePluginDeleteResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: _errors_pb2.ErrorResponse
    def __init__(self, error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...

class WorkspaceWipeRequest(_message.Message):
    __slots__ = ("workspace_id",)
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    workspace_id: str
    def __init__(self, workspace_id: _Optional[str] = ...) -> None: ...

class WorkspaceWipeResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: _errors_pb2.ErrorResponse
    def __init__(self, error: _Optional[_Union[_errors_pb2.ErrorResponse, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: space.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bspace.proto\x12\x05space\x1a\x0evalidate.proto\"\x95\x03\n\tContainer\x12/\n\x04name\x18\x01 \x01(\tB\x1c\xfa\x42\x19r\x17\x10\x01\x18?2\x11^([A-Za-z0-9-]+)$H\x00\x88\x01\x01\x12M\n\x05image\x18\x02 \x01(\tB9\xfa\x42\x36r4\x10\x01\x32-^[a-zA-Z0-9\\.\\/-]+([:@][a-zA-Z0-9\\.\\/:_-]*)?$\xd0\x01\x00H\x01\x88\x01\x01\x12&\n\x03\x65nv\x18\x03 \x03(\x0b\x32\x19.space.Container.EnvEntry\x12\x1e\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\x42\x08\"\x06\x18\xff\xff\x03(\x00H\x02\x88\x01\x01\x12\x32\n\x03\x63pu\x18\x05 \x01(\tB \xfa\x42\x1dr\x1b\x32\x16^[1-9]+(.[1-9]+)?[m]?$\xd0\x01\x00H\x03\x88\x01\x01\x12\x31\n\x06memory\x18\x06 \x01(\tB\x1c\xfa\x42\x19r\x17\x32\x12^[1-9]+(Mi|Gi|Ki)$\xd0\x01\x00H\x04\x88\x01\x01\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05_nameB\x08\n\x06_imageB\x07\n\x05_portB\x06\n\x04_cpuB\t\n\x07_memory\"\xa1\x03\n\x0f\x43ontainerUpdate\x12/\n\x04name\x18\x01 \x01(\tB\x1c\xfa\x42\x19r\x17\x10\x01\x18?2\x11^([A-Za-z0-9-]+)$H\x00\x88\x01\x01\x12M\n\x05image\x18\x02 \x01(\tB9\xfa\x42\x36r4\x10\x01\x32-^[a-zA-Z0-9\\.\\/-]+([:@][a-zA-Z0-9\\.\\/:_-]*)?$\xd0\x01\x00H\x01\x88\x01\x01\x12,\n\x03\x65nv\x18\x03 \x03(\x0b\x32\x1f.space.ContainerUpdate.EnvEntry\x12\x1e\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\x42\x08\"\x06\x18\xff\xff\x03(\x00H\x02\x88\x01\x01\x12\x32\n\x03\x63pu\x18\x05 \x01(\tB \xfa\x42\x1dr\x1b\x32\x16^[1-9]+(.[1-9]+)?[m]?$\xd0\x01\x00H\x03\x88\x01\x01\x12\x31\n\x06memory\x18\x06 \x01(\tB\x1c\xfa\x42\x19r\x17\x32\x12^[1-9]+(Mi|Gi|Ki)$\xd0\x01\x00H\x04\x88\x01\x01\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05_nameB\x08\n\x06_imageB\x07\n\x05_portB\x06\n\x04_cpuB\t\n\x07_memory\"\xf8\x01\n\x05Space\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12\x1e\n\x07user_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12\x19\n\x02id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x02\x88\x01\x01\x12\x1d\n\x06\x64omain\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\x90\x01\x01H\x03\x88\x01\x01\x12.\n\ncontainers\x18\x05 \x03(\x0b\x32\x10.space.ContainerB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\x07\n\x05_nameB\n\n\x08_user_idB\x05\n\x03_idB\t\n\x07_domain\"m\n\x0bSpaceUpdate\x12\x1d\n\x06\x64omain\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\x90\x01\x01H\x00\x88\x01\x01\x12\x34\n\ncontainers\x18\x05 \x03(\x0b\x32\x16.space.ContainerUpdateB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\t\n\x07_domain\"\xa5\x01\n\x12SpaceResponseError\x12$\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x11.space.SpaceErrorH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06reason\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07message\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_codeB\t\n\x07_statusB\t\n\x07_reasonB\n\n\x08_message\"\xb9\x01\n\x14SpaceCreationRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12\x1d\n\x06\x64omain\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\x90\x01\x01H\x01\x88\x01\x01\x12.\n\ncontainers\x18\x05 \x03(\x0b\x32\x10.space.ContainerB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\x07\n\x05_nameB\t\n\x07_domain\"c\n\x15SpaceCreationResponse\x12 \n\x05space\x18\x01 \x01(\x0b\x32\x0c.space.SpaceH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_spaceB\t\n\x07_status\"Z\n\x0fSpaceGetRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"^\n\x10SpaceGetResponse\x12 \n\x05space\x18\x01 \x01(\x0b\x32\x0c.space.SpaceH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_spaceB\t\n\x07_status\"_\n\x14SpaceDeletionRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"7\n\x15SpaceDeletionResponse\x12\x13\n\x06status\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_status\"b\n\x10SpaceListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"1\n\x11SpaceListResponse\x12\x1c\n\x06spaces\x18\x01 \x03(\x0b\x32\x0c.space.Space\"\x8f\x01\n\x12SpaceUpdateRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12&\n\x05space\x18\x02 \x01(\x0b\x32\x12.space.SpaceUpdateH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_space\"a\n\x13SpaceUpdateResponse\x12 \n\x05space\x18\x01 \x01(\x0b\x32\x0c.space.SpaceH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_spaceB\t\n\x07_status*\xaf\x01\n\nSpaceError\x12\x12\n\x0eSPACE_NO_ERROR\x10\x00\x12\x18\n\x14SPACE_ALREADY_EXISTS\x10\x01\x12\x13\n\x0fSPACE_NOT_FOUND\x10\x02\x12\x15\n\x11SPACE_NOT_UPDATED\x10\x03\x12&\n\"SPACE_MUST_HAVE_ONE_CONTAINER_PORT\x10\x04\x12\x1f\n\x1bSPACE_SUBSCRIPTION_REQUIRED\x10\x05\x42.Z,github.com/jupyter-naas/naas-models/go/spaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'space_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/jupyter-naas/naas-models/go/space'
  _globals['_CONTAINER_ENVENTRY']._loaded_options = None
  _globals['_CONTAINER_ENVENTRY']._serialized_options = b'8\001'
  _globals['_CONTAINER'].fields_by_name['name']._loaded_options = None
  _globals['_CONTAINER'].fields_by_name['name']._serialized_options = b'\372B\031r\027\020\001\030?2\021^([A-Za-z0-9-]+)$'
  _globals['_CONTAINER'].fields_by_name['image']._loaded_options = None
  _globals['_CONTAINER'].fields_by_name['image']._serialized_options = b'\372B6r4\020\0012-^[a-zA-Z0-9\\.\\/-]+([:@][a-zA-Z0-9\\.\\/:_-]*)?$\320\001\000'
  _globals['_CONTAINER'].fields_by_name['port']._loaded_options = None
  _globals['_CONTAINER'].fields_by_name['port']._serialized_options = b'\372B\010\"\006\030\377\377\003(\000'
  _globals['_CONTAINER'].fields_by_name['cpu']._loaded_options = None
  _globals['_CONTAINER'].fields_by_name['cpu']._serialized_options = b'\372B\035r\0332\026^[1-9]+(.[1-9]+)?[m]?$\320\001\000'
  _globals['_CONTAINER'].fields_by_name['memory']._loaded_options = None
  _globals['_CONTAINER'].fields_by_name['memory']._serialized_options = b'\372B\031r\0272\022^[1-9]+(Mi|Gi|Ki)$\320\001\000'
  _globals['_CONTAINERUPDATE_ENVENTRY']._loaded_options = None
  _globals['_CONTAINERUPDATE_ENVENTRY']._serialized_options = b'8\001'
  _globals['_CONTAINERUPDATE'].fields_by_name['name']._loaded_options = None
  _globals['_CONTAINERUPDATE'].fields_by_name['name']._serialized_options = b'\372B\031r\027\020\001\030?2\021^([A-Za-z0-9-]+)$'
  _globals['_CONTAINERUPDATE'].fields_by_name['image']._loaded_options = None
  _globals['_CONTAINERUPDATE'].fields_by_name['image']._serialized_options = b'\372B6r4\020\0012-^[a-zA-Z0-9\\.\\/-]+([:@][a-zA-Z0-9\\.\\/:_-]*)?$\320\001\000'
  _globals['_CONTAINERUPDATE'].fields_by_name['port']._loaded_options = None
  _globals['_CONTAINERUPDATE'].fields_by_name['port']._serialized_options = b'\372B\010\"\006\030\377\377\003(\000'
  _globals['_CONTAINERUPDATE'].fields_by_name['cpu']._loaded_options = None
  _globals['_CONTAINERUPDATE'].fields_by_name['cpu']._serialized_options = b'\372B\035r\0332\026^[1-9]+(.[1-9]+)?[m]?$\320\001\000'
  _globals['_CONTAINERUPDATE'].fields_by_name['memory']._loaded_options = None
  _globals['_CONTAINERUPDATE'].fields_by_name['memory']._serialized_options = b'\372B\031r\0272\022^[1-9]+(Mi|Gi|Ki)$\320\001\000'
  _globals['_SPACE'].fields_by_name['name']._loaded_options = None
  _globals['_SPACE'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_SPACE'].fields_by_name['user_id']._loaded_options = None
  _globals['_SPACE'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_SPACE'].fields_by_name['id']._loaded_options = None
  _globals['_SPACE'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_SPACE'].fields_by_name['domain']._loaded_options = None
  _globals['_SPACE'].fields_by_name['domain']._serialized_options = b'\372B\005r\003\220\001\001'
  _globals['_SPACE'].fields_by_name['containers']._loaded_options = None
  _globals['_SPACE'].fields_by_name['containers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_SPACEUPDATE'].fields_by_name['domain']._loaded_options = None
  _globals['_SPACEUPDATE'].fields_by_name['domain']._serialized_options = b'\372B\005r\003\220\001\001'
  _globals['_SPACEUPDATE'].fields_by_name['containers']._loaded_options = None
  _globals['_SPACEUPDATE'].fields_by_name['containers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_SPACECREATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_SPACECREATIONREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_SPACECREATIONREQUEST'].fields_by_name['domain']._loaded_options = None
  _globals['_SPACECREATIONREQUEST'].fields_by_name['domain']._serialized_options = b'\372B\005r\003\220\001\001'
  _globals['_SPACECREATIONREQUEST'].fields_by_name['containers']._loaded_options = None
  _globals['_SPACECREATIONREQUEST'].fields_by_name['containers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_SPACEGETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_SPACEGETREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_SPACEDELETIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_SPACEDELETIONREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_SPACEUPDATEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_SPACEUPDATEREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_SPACEERROR']._serialized_start=2424
  _globals['_SPACEERROR']._serialized_end=2599
  _globals['_CONTAINER']._serialized_start=39
  _globals['_CONTAINER']._serialized_end=444
  _globals['_CONTAINER_ENVENTRY']._serialized_start=355
  _globals['_CONTAINER_ENVENTRY']._serialized_end=397
  _globals['_CONTAINERUPDATE']._serialized_start=447
  _globals['_CONTAINERUPDATE']._serialized_end=864
  _globals['_CONTAINERUPDATE_ENVENTRY']._serialized_start=355
  _globals['_CONTAINERUPDATE_ENVENTRY']._serialized_end=397
  _globals['_SPACE']._serialized_start=867
  _globals['_SPACE']._serialized_end=1115
  _globals['_SPACEUPDATE']._serialized_start=1117
  _globals['_SPACEUPDATE']._serialized_end=1226
  _globals['_SPACERESPONSEERROR']._serialized_start=1229
  _globals['_SPACERESPONSEERROR']._serialized_end=1394
  _globals['_SPACECREATIONREQUEST']._serialized_start=1397
  _globals['_SPACECREATIONREQUEST']._serialized_end=1582
  _globals['_SPACECREATIONRESPONSE']._serialized_start=1584
  _globals['_SPACECREATIONRESPONSE']._serialized_end=1683
  _globals['_SPACEGETREQUEST']._serialized_start=1685
  _globals['_SPACEGETREQUEST']._serialized_end=1775
  _globals['_SPACEGETRESPONSE']._serialized_start=1777
  _globals['_SPACEGETRESPONSE']._serialized_end=1871
  _globals['_SPACEDELETIONREQUEST']._serialized_start=1873
  _globals['_SPACEDELETIONREQUEST']._serialized_end=1968
  _globals['_SPACEDELETIONRESPONSE']._serialized_start=1970
  _globals['_SPACEDELETIONRESPONSE']._serialized_end=2025
  _globals['_SPACELISTREQUEST']._serialized_start=2027
  _globals['_SPACELISTREQUEST']._serialized_end=2125
  _globals['_SPACELISTRESPONSE']._serialized_start=2127
  _globals['_SPACELISTRESPONSE']._serialized_end=2176
  _globals['_SPACEUPDATEREQUEST']._serialized_start=2179
  _globals['_SPACEUPDATEREQUEST']._serialized_end=2322
  _globals['_SPACEUPDATERESPONSE']._serialized_start=2324
  _globals['_SPACEUPDATERESPONSE']._serialized_end=2421
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asset.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
import naas_models.validate_pb2 as validate__pb2
import naas_models.errors_pb2 as errors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61sset.proto\x12\x05\x61sset\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x0evalidate.proto\x1a\x0c\x65rrors.proto\"\x9e\x04\n\x0eObjectMetadata\x12\x15\n\x08provider\x18\x01 \x01(\tH\x00\x88\x01\x01\x12!\n\x14provider_bucket_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x02\x88\x01\x01\x12\x19\n\x0cstorage_name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06prefix\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0bobject_name\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x19\n\x0c\x63ontent_type\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1b\n\x0e\x63ontent_length\x18\x08 \x01(\tH\x07\x88\x01\x01\x12:\n\x11object_updated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x08\x88\x01\x01\x12\x1b\n\x0eobject_version\x18\n \x01(\tH\t\x88\x01\x01\x12\x15\n\x08metadata\x18\x0b \x01(\tH\n\x88\x01\x01\x42\x0b\n\t_providerB\x17\n\x15_provider_bucket_nameB\x0f\n\r_workspace_idB\x0f\n\r_storage_nameB\t\n\x07_prefixB\x0e\n\x0c_object_nameB\x0f\n\r_content_typeB\x11\n\x0f_content_lengthB\x14\n\x12_object_updated_atB\x11\n\x0f_object_versionB\x0b\n\t_metadata\"\xff\x05\n\x05\x41sset\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x18\n\x0bobject_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nvisibility\x18\x03 \x01(\tH\x02\x88\x01\x01\x12 \n\x13\x63ontent_disposition\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08password\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x10\n\x03url\x18\x06 \x01(\tH\x05\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x07 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x06\x88\x01\x01\x12\x19\n\x0cstorage_name\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x13\n\x06prefix\x18\t \x01(\tH\x08\x88\x01\x01\x12\x1b\n\x0eobject_version\x18\n \x01(\tH\t\x88\x01\x01\x12\x19\n\x0c\x63ontent_type\x18\x0b \x01(\tH\n\x88\x01\x01\x12:\n\x11object_updated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x0b\x88\x01\x01\x12\x39\n\x10\x61sset_created_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x0c\x88\x01\x01\x12\x1e\n\x07user_id\x18\x0e \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\r\x88\x01\x01\x12\x15\n\x08provider\x18\x0f \x01(\tH\x0e\x88\x01\x01\x12!\n\x14provider_bucket_name\x18\x10 \x01(\tH\x0f\x88\x01\x01\x42\x05\n\x03_idB\x0e\n\x0c_object_nameB\r\n\x0b_visibilityB\x16\n\x14_content_dispositionB\x0b\n\t_passwordB\x06\n\x04_urlB\x0f\n\r_workspace_idB\x0f\n\r_storage_nameB\t\n\x07_prefixB\x11\n\x0f_object_versionB\x0f\n\r_content_typeB\x14\n\x12_object_updated_atB\x13\n\x11_asset_created_atB\n\n\x08_user_idB\x0b\n\t_providerB\x17\n\x15_provider_bucket_name\"\xd1\x02\n\rAssetCreation\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x19\n\x0cstorage_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0bobject_name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1b\n\x0eobject_version\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\nvisibility\x18\x05 \x01(\tH\x04\x88\x01\x01\x12 \n\x13\x63ontent_disposition\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x15\n\x08password\x18\x07 \x01(\tH\x06\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0f\n\r_storage_nameB\x0e\n\x0c_object_nameB\x11\n\x0f_object_versionB\r\n\x0b_visibilityB\x16\n\x14_content_dispositionB\x0b\n\t_password\"o\n\x0b\x41ssetUpdate\x12\x17\n\nvisibility\x18\x01 \x01(\tH\x00\x88\x01\x01\x12 \n\x13\x63ontent_disposition\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_visibilityB\x16\n\x14_content_disposition\"\x98\x01\n\x10\x41ssetListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x16\n\tpage_size\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"f\n\x11\x41ssetListResponse\x12\x1c\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x0c.asset.Asset\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x90\x01\n\x12\x41ssetCreateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x31\n\x0e\x61sset_creation\x18\x02 \x01(\x0b\x32\x14.asset.AssetCreationH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x11\n\x0f_asset_creation\"v\n\x13\x41ssetCreateResponse\x12 \n\x05\x61sset\x18\x01 \x01(\x0b\x32\x0c.asset.AssetH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x08\n\x06_assetB\x08\n\x06_error\"u\n\x0f\x41ssetGetRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x1f\n\x08\x61sset_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0b\n\t_asset_id\"s\n\x10\x41ssetGetResponse\x12 \n\x05\x61sset\x18\x01 \x01(\x0b\x32\x0c.asset.AssetH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x08\n\x06_assetB\x08\n\x06_error\"{\n\x15\x41ssetGetObjectRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x1f\n\x08\x61sset_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0b\n\t_asset_id\"g\n\x16\x41ssetGetObjectResponse\x12\x10\n\x03url\x18\x01 \x01(\tH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x06\n\x04_urlB\x08\n\x06_error\"\x8a\x01\n\x12\x41ssetUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12-\n\x0c\x61sset_update\x18\x02 \x01(\x0b\x32\x12.asset.AssetUpdateH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0f\n\r_asset_update\"v\n\x13\x41ssetUpdateResponse\x12 \n\x05\x61sset\x18\x01 \x01(\x0b\x32\x0c.asset.AssetH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x08\n\x06_assetB\x08\n\x06_error\"x\n\x12\x41ssetDeleteRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x1f\n\x08\x61sset_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0b\n\t_asset_id\"J\n\x13\x41ssetDeleteResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error*\x84\x01\n\nAssetError\x12\x12\n\x0e\x41SSET_NO_ERROR\x10\x00\x12\x13\n\x0f\x41SSET_NOT_FOUND\x10\x01\x12\x18\n\x14\x41SSET_ALREADY_EXISTS\x10\x02\x12\x17\n\x13\x41SSET_REQUEST_ERROR\x10\x03\x12\x1a\n\x15INTERNAL_SERVER_ERROR\x10\xe8\x07\x42.Z,github.com/jupyter-naas/naas-models/go/assetb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/jupyter-naas/naas-models/go/asset'
  _globals['_OBJECTMETADATA'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_OBJECTMETADATA'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSET'].fields_by_name['id']._loaded_options = None
  _globals['_ASSET'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSET'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSET'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSET'].fields_by_name['user_id']._loaded_options = None
  _globals['_ASSET'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETCREATION'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETCREATION'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETLISTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETLISTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETCREATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETCREATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETGETREQUEST'].fields_by_name['asset_id']._loaded_options = None
  _globals['_ASSETGETREQUEST'].fields_by_name['asset_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETGETOBJECTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETGETOBJECTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETGETOBJECTREQUEST'].fields_by_name['asset_id']._loaded_options = None
  _globals['_ASSETGETOBJECTREQUEST'].fields_by_name['asset_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETDELETEREQUEST'].fields_by_name['asset_id']._loaded_options = None
  _globals['_ASSETDELETEREQUEST'].fields_by_name['asset_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETERROR']._serialized_start=3305
  _globals['_ASSETERROR']._serialized_end=3437
  _globals['_OBJECTMETADATA']._serialized_start=86
  _globals['_OBJECTMETADATA']._serialized_end=628
  _globals['_ASSET']._serialized_start=631
  _globals['_ASSET']._serialized_end=1398
  _globals['_ASSETCREATION']._serialized_start=1401
  _globals['_ASSETCREATION']._serialized_end=1738
  _globals['_ASSETUPDATE']._serialized_start=1740
  _globals['_ASSETUPDATE']._serialized_end=1851
  _globals['_ASSETLISTREQUEST']._serialized_start=1854
  _globals['_ASSETLISTREQUEST']._serialized_end=2006
  _globals['_ASSETLISTRESPONSE']._serialized_start=2008
  _globals['_ASSETLISTRESPONSE']._serialized_end=2110
  _globals['_ASSETCREATEREQUEST']._serialized_start=2113
  _globals['_ASSETCREATEREQUEST']._serialized_end=2257
  _globals['_ASSETCREATERESPONSE']._serialized_start=2259
  _globals['_ASSETCREATERESPONSE']._serialized_end=2377
  _globals['_ASSETGETREQUEST']._serialized_start=2379
  _globals['_ASSETGETREQUEST']._serialized_end=2496
  _globals['_ASSETGETRESPONSE']._serialized_start=2498
  _globals['_ASSETGETRESPONSE']._serialized_end=2613
  _globals['_ASSETGETOBJECTREQUEST']._serialized_start=2615
  _globals['_ASSETGETOBJECTREQUEST']._serialized_end=2738
  _globals['_ASSETGETOBJECTRESPONSE']._serialized_start=2740
  _globals['_ASSETGETOBJECTRESPONSE']._serialized_end=2843
  _globals['_ASSETUPDATEREQUEST']._serialized_start=2846
  _globals['_ASSETUPDATEREQUEST']._serialized_end=2984
  _globals['_ASSETUPDATERESPONSE']._serialized_start=2986
  _globals['_ASSETUPDATERESPONSE']._serialized_end=3104
  _globals['_ASSETDELETEREQUEST']._serialized_start=3106
  _globals['_ASSETDELETEREQUEST']._serialized_end=3226
  _globals['_ASSETDELETERESPONSE']._serialized_start=3228
  _globals['_ASSETDELETERESPONSE']._serialized_end=3302
# @@protoc_insertion_point(module_scope)



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.3.3.1](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.12.3 
from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic import ConfigDict
from pydantic import Field
from uuid import UUID
import typing

class StorageError(IntEnum):
    STORAGE_NO_ERROR = 0
    STORAGE_ALREADY_EXIST = 1
    STORAGE_NOT_FOUND = 2
    INTERNAL_SERVER_ERROR = 1000


class ObjectError(IntEnum):
    OBJECT_NO_ERROR = 0
    OBJECT_ALREADY_EXIST = 1
    OBJECT_SIZE_ERROR = 2
    OBJECT_NOT_FOUND = 3
    OBJECT_DIR_NOT_EMPTY = 4


class CredentialsError(IntEnum):
    CREDENTIALS_NO_ERROR = 0

class Storage(BaseModel):
    name: typing.Optional[str] = Field(default="")

class Object(BaseModel):
    name: typing.Optional[str] = Field(default="")
    type: typing.Optional[str] = Field(default="")
    prefix: typing.Optional[str] = Field(default="")
    size: typing.Optional[str] = Field(default="")
    lastmodified: typing.Optional[str] = Field(default="")

class StorageResponseError(BaseModel):
    model_config = ConfigDict(validate_default=True)
    code: typing.Optional[StorageError] = Field(default=0)
    message: typing.Optional[str] = Field(default="")

class ObjectResponseError(BaseModel):
    model_config = ConfigDict(validate_default=True)
    code: typing.Optional[ObjectError] = Field(default=0)
    message: typing.Optional[str] = Field(default="")

class ObjectStorageCredentialsResponseError(BaseModel):
    model_config = ConfigDict(validate_default=True)
    code: typing.Optional[CredentialsError] = Field(default=0)
    message: typing.Optional[str] = Field(default="")

class StorageListRequest(BaseModel):
    storage: typing.Optional[Storage] = Field(default_factory=Storage)
    object: typing.Optional[Object] = Field(default_factory=Object)

class StorageListResponse(BaseModel):
    storage: typing.List[Storage] = Field(default_factory=list)
    error: typing.Optional[StorageResponseError] = Field(default_factory=StorageResponseError)

class StorageCreateRequest(BaseModel):
    storage: typing.Optional[Storage] = Field(default_factory=Storage)

class StorageCreateResponse(BaseModel):
    storage: typing.Optional[Storage] = Field(default_factory=Storage)
    error: typing.Optional[StorageResponseError] = Field(default_factory=StorageResponseError)

class StorageDeleteRequest(BaseModel):
    storage: typing.Optional[Storage] = Field(default_factory=Storage)

class StorageDeleteResponse(BaseModel):
    error: typing.Optional[StorageResponseError] = Field(default_factory=StorageResponseError)

class StorageListObjectRequest(BaseModel):
    storage: typing.Optional[Storage] = Field(default_factory=Storage)
    object: typing.Optional[Object] = Field(default_factory=Object)

class StorageListObjectResponse(BaseModel):
    object: typing.List[Object] = Field(default_factory=list)
    error: typing.Optional[StorageResponseError] = Field(default_factory=StorageResponseError)

class ObjectCreateRequest(BaseModel):
    storage: typing.Optional[Storage] = Field(default_factory=Storage)
    object: typing.Optional[Object] = Field(default_factory=Object)

class ObjectCreateResponse(BaseModel):
    error: typing.Optional[ObjectResponseError] = Field(default_factory=ObjectResponseError)

class ObjectListRequest(BaseModel):
    storage: typing.Optional[Storage] = Field(default_factory=Storage)
    object: typing.Optional[Object] = Field(default_factory=Object)

class ObjectListResponse(BaseModel):
    object: typing.List[Object] = Field(default_factory=list)
    error: typing.Optional[ObjectResponseError] = Field(default_factory=ObjectResponseError)

class ObjectGetRequest(BaseModel):
    storage: typing.Optional[Storage] = Field(default_factory=Storage)
    object: typing.Optional[Object] = Field(default_factory=Object)

class ObjectGetResponse(BaseModel):
    object: typing.Optional[Object] = Field(default_factory=Object)
    error: typing.Optional[ObjectResponseError] = Field(default_factory=ObjectResponseError)

class ObjectDeleteRequest(BaseModel):
    object: typing.Optional[Object] = Field(default_factory=Object)

class ObjectDeleteResponse(BaseModel):
    error: typing.Optional[ObjectResponseError] = Field(default_factory=ObjectResponseError)

class ObjectStorageS3Credentials(BaseModel):
    """
     Credentials
    """

    endpoint_url: typing.Optional[str] = Field(default="")
    region_name: typing.Optional[str] = Field(default="")
    access_key_id: typing.Optional[str] = Field(default="")
    secret_key: typing.Optional[str] = Field(default="")
    session_token: typing.Optional[str] = Field(default="")
    expiration: typing.Optional[str] = Field(default="")

class ObjectStorageAzureCredentials(BaseModel):
    endpoint_url: typing.Optional[str] = Field(default="")
    access_key_id: typing.Optional[str] = Field(default="")
    secret_key: typing.Optional[str] = Field(default="")

class ObjectStorageCredentials(BaseModel):
    s3: ObjectStorageS3Credentials = Field(default_factory=ObjectStorageS3Credentials)

class ObjectStorageCredentialsRequest(BaseModel):
#optional string workspace_id = 1;
    storage: typing.Optional[Storage] = Field(default_factory=Storage)

class ObjectStorageCredentialsResponse(BaseModel):
    credentials: typing.Optional[ObjectStorageCredentials] = Field(default_factory=ObjectStorageCredentials)
    error: typing.Optional[ObjectStorageCredentialsResponseError] = Field(default_factory=ObjectStorageCredentialsResponseError)

class StorageObjectPublicUrlRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="")
    storage_name: typing.Optional[str] = Field(default="")
    prefix: typing.Optional[str] = Field(default="")
    object_name: typing.Optional[str] = Field(default="")

class StorageObjectPublicUrlResponse(BaseModel):
    url: typing.Optional[str] = Field(default="")
    error: typing.Optional[ObjectResponseError] = Field(default_factory=ObjectResponseError)
